@@ -1,4 +1,5 @@
 from bxcommon.messages.bloxroute.bloxroute_message_type import BloxrouteMessageType
+from bxcommon.messages.bloxroute.v13.pong_message_converter_v13 import pong_message_converter_v13
 from bxcommon.messages.bloxroute.v8.broadcast_message_converter_v8 import broadcast_message_converter_v8
 from bxcommon.messages.bloxroute.v9.bdn_performance_stats_message_converter_v9 \
     import bdn_performance_stats_message_converter_v9
@@ -11,6 +12,7 @@ class _MessageConverterFactoryV8(AbstractMessageConverterFactory):
     _MESSAGE_CONVERTER_MAPPING = {
         BloxrouteMessageType.BDN_PERFORMANCE_STATS: bdn_performance_stats_message_converter_v9,
         BloxrouteMessageType.BROADCAST: broadcast_message_converter_v8,
+        BloxrouteMessageType.PONG: pong_message_converter_v13
     }
 
     def get_message_converter(self, msg_type) -> AbstractMessageConverter:
