@@ -17,8 +17,8 @@ from bxcommon.messages.bloxroute import short_ids_serializer
 from bxcommon.models.quota_type_model import QuotaType
 from bxcommon.models.transaction_info import TransactionSearchResult, TransactionInfo
 from bxcommon.utils import memory_utils, convert
-from bxcommon.utils.crypto import SHA256_HASH_LEN
 from bxcommon.utils.expiration_queue import ExpirationQueue
+from bxcommon.utils.crypto import SHA256_HASH_LEN
 from bxcommon.utils.memory_utils import ObjectSize
 from bxcommon.utils.object_hash import Sha256Hash
 from bxcommon.utils.stats import hooks
@@ -135,7 +135,6 @@ class TransactionService:
     _tx_cache_key_to_contents: Dict[TransactionCacheKeyType, Union[bytearray, memoryview]]
     _tx_cache_key_to_short_ids: Dict[TransactionCacheKeyType, Set[int]]
     _tx_assignment_expire_queue: ExpirationQueue[int]
-    _tx_hash_to_time_removed: OrderedDict
     tx_hashes_without_short_id: ExpirationQueue[Sha256Hash]
     tx_hashes_without_content: ExpirationQueue[Sha256Hash]  # but has short ID
 
@@ -175,7 +174,9 @@ class TransactionService:
         self._tx_assignment_expire_queue = ExpirationQueue(node.opts.sid_expire_time)
         self.tx_hashes_without_short_id = ExpirationQueue(constants.TX_CONTENT_NO_SID_EXPIRE_S)
         self.tx_hashes_without_content = ExpirationQueue(constants.TX_CONTENT_NO_SID_EXPIRE_S)
-        self._tx_hash_to_time_removed = OrderedDict()
+        self.network = None
+        if self.network_num in self.node.opts.blockchain_networks:
+            self.network = self.node.opts.blockchain_networks[self.network_num]
 
         self._final_tx_confirmations_count = self._get_final_tx_confirmations_count()
         self._tx_content_memory_limit = self._get_tx_contents_memory_limit()
@@ -195,10 +196,6 @@ class TransactionService:
                 constants.DUMP_REMOVED_SHORT_IDS_INTERVAL_S,
                 self._dump_removed_short_ids
             )
-        self.node.alarm_queue.register_alarm(
-            constants.REMOVED_TRANSACTIONS_HISTORY_CLEANUP_INTERVAL_S,
-            self._cleanup_removed_transactions_history
-        )
 
         self.total_cached_transactions = total_cached_transactions.labels(network_num)
         self.total_cached_transactions.set_function(
@@ -312,14 +309,20 @@ class TransactionService:
             if short_id in self._short_id_to_tx_cache_key:
                 transaction_cache_key = self._short_id_to_tx_cache_key[short_id]
                 if transaction_cache_key in self._tx_cache_key_to_contents:
-                    found.append(TransactionInfo(self._tx_cache_key_to_hash(transaction_cache_key),
-                                                 self._tx_cache_key_to_contents[transaction_cache_key],
-                                                 short_id))
+                    found.append(TransactionInfo(
+                        self._tx_cache_key_to_hash(transaction_cache_key),
+                        self._tx_cache_key_to_contents[transaction_cache_key],
+                        short_id
+                    ))
                 else:
-                    missing.append(short_id)
+                    missing.append(TransactionInfo(
+                        self._tx_cache_key_to_hash(transaction_cache_key),
+                        None,
+                        short_id
+                    ))
                     logger.trace("Short id {} was requested but is unknown.", short_id)
             else:
-                missing.append(short_id)
+                missing.append(TransactionInfo(None, None, short_id))
                 logger.trace("Short id {} was requested but is unknown.", short_id)
 
         return TransactionSearchResult(found, missing)
@@ -368,22 +371,6 @@ class TransactionService:
     def has_cache_key_no_sid_entry(self, transaction_hash: Sha256Hash) -> bool:
         return transaction_hash in self.tx_hashes_without_short_id.queue
 
-    def removed_transaction(self, transaction_hash: Sha256Hash) -> bool:
-        """
-        Check if transaction was seen and removed from cache
-        :param transaction_hash: transaction hash
-        :return: Boolean indicating in transaction was seen
-        """
-        return self.removed_transaction_by_cache_key(self._tx_hash_to_cache_key(transaction_hash))
-
-    def removed_transaction_by_cache_key(self, cache_key: TransactionCacheKeyType) -> bool:
-        """
-        Check if transaction was seen and removed from cache
-        :param cache_key: transaction cache key
-        :return: Boolean indicating in transaction was seen
-        """
-        return cache_key in self._tx_hash_to_time_removed
-
     def remove_sid_by_tx_hash(self, transaction_hash: Sha256Hash) -> None:
         transaction_cache_key = self._tx_hash_to_cache_key(transaction_hash)
         if transaction_cache_key in self._tx_cache_key_to_contents:
@@ -396,22 +383,31 @@ class TransactionService:
                     del self._short_id_to_tx_cache_key[short_id]
                     self._tx_assignment_expire_queue.remove(short_id)
 
-    def assign_short_id(self, transaction_hash: Sha256Hash, short_id: int) -> None:
+    def assign_short_id(
+        self,
+        transaction_hash: Sha256Hash,
+        short_id: int,
+        transaction_cache_key: Optional[TransactionCacheKeyType] = None
+    ) -> None:
         """
         Adds short id mapping for transaction and schedules an alarm to cleanup entry on expiration.
         :param transaction_hash: transaction long hash
         :param short_id: short id to be mapped to transaction
+        :param transaction_cache_key: transaction cache key
         """
-        transaction_cache_key = self._tx_hash_to_cache_key(transaction_hash)
+        if not transaction_cache_key:
+            transaction_cache_key = self._tx_hash_to_cache_key(transaction_hash)
         has_contents = transaction_cache_key in self._tx_cache_key_to_contents
         self.assign_short_id_base(transaction_hash, transaction_cache_key, short_id, has_contents, True)
 
-    def assign_short_id_base(self,
-                             transaction_hash: Sha256Hash,
-                             transaction_cache_key: TransactionCacheKeyType,
-                             short_id: int,
-                             has_contents: bool,
-                             call_to_assign_short_id: bool):
+    def assign_short_id_base(
+        self,
+        transaction_hash: Sha256Hash,
+        transaction_cache_key: Optional[TransactionCacheKeyType],
+        short_id: int,
+        has_contents: bool,
+        call_to_assign_short_id: bool
+    ) -> None:
         """
         Base method to assign short id for a transaction
 
@@ -432,11 +428,15 @@ class TransactionService:
         if not has_contents:
             self.tx_hashes_without_content.add(transaction_hash)
             if not self.tx_without_content_alarm_scheduled:
-                self.node.alarm_queue.register_alarm(constants.TX_CONTENT_NO_SID_EXPIRE_S,
-                                                     self.expire_sid_without_content)
+                self.node.alarm_queue.register_alarm(
+                    constants.TX_CONTENT_NO_SID_EXPIRE_S,
+                    self.expire_sid_without_content
+                )
                 self.tx_without_content_alarm_scheduled = True
 
         if call_to_assign_short_id:
+            if not transaction_cache_key:
+                transaction_cache_key = self._tx_hash_to_cache_key(transaction_hash)
             self._tx_cache_key_to_short_ids[transaction_cache_key].add(short_id)
             self._short_id_to_tx_cache_key[short_id] = transaction_cache_key
         self._tx_assignment_expire_queue.add(short_id)
@@ -510,7 +510,6 @@ class TransactionService:
 
         if transaction_contents is not None:
             self._total_tx_contents_size += len(transaction_contents) - previous_size
-            self.node.log_txs_network_content(self.network_num, wrap_sha256(transaction_hash), transaction_contents)
             if call_set_contents:
                 self._tx_cache_key_to_contents[transaction_cache_key] = transaction_contents
         elif transaction_contents_length is not None:
@@ -520,7 +519,6 @@ class TransactionService:
 
         self._memory_limit_clean_up()
 
-
     def remove_transaction_by_tx_hash(
         self,
         transaction_hash: Sha256Hash,
@@ -562,15 +560,12 @@ class TransactionService:
                 self._tx_assignment_expire_queue.remove(short_id)
                 if self.node.opts.dump_removed_short_ids:
                     self._removed_short_ids.add(short_id)
-
-                self._tx_hash_to_time_removed[transaction_cache_key] = time.time()
         else:
             short_ids = None
 
         if transaction_cache_key in self._tx_cache_key_to_contents:
             self._total_tx_contents_size -= len(self._tx_cache_key_to_contents[transaction_cache_key])
             del self._tx_cache_key_to_contents[transaction_cache_key]
-            self._tx_hash_to_time_removed[transaction_cache_key] = time.time()
             removed_txns += 1
 
         logger.trace("Removed transaction: {}, with {} associated short ids and {} contents.", transaction_hash,
@@ -632,7 +627,6 @@ class TransactionService:
                 if transaction_cache_key in self._tx_cache_key_to_contents:
                     self._total_tx_contents_size -= len(self._tx_cache_key_to_contents[transaction_cache_key])
                     del self._tx_cache_key_to_contents[transaction_cache_key]
-                    self._tx_hash_to_time_removed[transaction_cache_key] = time.time()
 
                 # Delete short ids from _tx_cache_key_to_short_ids after iterating short_ids.
                 # Otherwise extension implementation disposes short_ids list after this line
@@ -760,6 +754,13 @@ class TransactionService:
     def get_tracked_seen_block_count(self) -> int:
         return len(self._short_ids_seen_in_block)
 
+    def get_short_id_assign_time(self, short_id: int) -> float:
+        if short_id in self._tx_assignment_expire_queue.queue:
+            return self._tx_assignment_expire_queue.queue[short_id]
+        else:
+            logger.warning(log_messages.MISSING_ASSIGN_TIME_FOR_SHORT_ID, short_id)
+            return 0.0
+
     def expire_old_assignments(self) -> float:
         """
         Clean up expired short ids.
@@ -873,46 +874,6 @@ class TransactionService:
             short_ids
         )
 
-    def process_gateway_transaction_from_bdn(
-        self,
-        transaction_hash: Sha256Hash,
-        short_id: int,
-        transaction_contents: Union[bytearray, memoryview],
-        is_compact: bool
-    ) -> TransactionFromBdnGatewayProcessingResult:
-
-        # don't check removed_contents for messages from BDN
-        if (
-            not short_id
-            and self.has_transaction_short_id(transaction_hash)
-            and self.has_transaction_contents(transaction_hash)
-        ):
-            return TransactionFromBdnGatewayProcessingResult(ignore_seen=True)
-
-        existing_short_ids = self.get_short_ids(transaction_hash)
-        if (self.has_transaction_contents(transaction_hash) or is_compact) \
-            and short_id and short_id in existing_short_ids:
-            return TransactionFromBdnGatewayProcessingResult(existing_short_id=True)
-
-        assigned_short_id = False
-        set_content = False
-
-        if short_id and short_id not in existing_short_ids:
-            self.assign_short_id(transaction_hash, short_id)
-            assigned_short_id = True
-
-        existing_contents = self.has_transaction_contents(transaction_hash)
-
-        if not is_compact and not existing_contents:
-            self.set_transaction_contents(transaction_hash, transaction_contents)
-            set_content = True
-
-        return TransactionFromBdnGatewayProcessingResult(
-            assigned_short_id=assigned_short_id,
-            existing_contents=existing_contents,
-            set_content=set_content
-        )
-
     def log_block_transaction_cleanup_stats(self, block_hash: Sha256Hash, tx_count: int, tx_before_cleanup: int,
                                             tx_after_cleanup: int, short_id_count_before_cleanup: int,
                                             short_id_count_after_cleanup: int):
@@ -1024,18 +985,6 @@ class TransactionService:
             size_type=size_type
         )
 
-        hooks.add_obj_mem_stats(
-            class_name,
-            self.network_num,
-            self._tx_hash_to_time_removed,
-            "tx_hash_to_time_removed",
-            self.get_collection_mem_stats(self._tx_hash_to_time_removed,
-                                          len(self._tx_hash_to_time_removed) * SHA256_HASH_LEN),
-            object_item_count=len(self._tx_hash_to_time_removed),
-            object_type=memory_utils.ObjectType.BASE,
-            size_type=size_type
-        )
-
         hooks.add_obj_mem_stats(
             class_name,
             self.network_num,
@@ -1144,7 +1093,7 @@ class TransactionService:
         if self._is_exceeding_memory_limit() and not self._tx_assignment_expire_queue:
             logger.warning(log_messages.SID_MEMORY_MANAGEMENT_FAILURE, self.get_cache_state_json())
             removed_tx_count += len(self._tx_cache_key_to_contents)
-            self._clear()
+            self.clear()
 
         self._total_tx_removed_by_memory_limit += removed_tx_count
         logger.trace("Removed {} oldest transactions from transaction service cache. Size after clean up: {}",
@@ -1154,12 +1103,13 @@ class TransactionService:
         """
         Returns configuration value of number of block confirmations required before transaction can be removed
         """
-        for blockchain_network in self.node.opts.blockchain_networks:
-            if blockchain_network.network_num == self.network_num:
-                return blockchain_network.final_tx_confirmations_count
+        if self.network:
+            return self.network.final_tx_confirmations_count
 
-        logger.warning(log_messages.UNABLE_TO_DETERMINE_TX_FINAL_CONFIRMATIONS_COUNT,
-                       self.network_num, self.DEFAULT_FINAL_TX_CONFIRMATIONS_COUNT)
+        logger.warning(
+            log_messages.UNABLE_TO_DETERMINE_TX_FINAL_CONFIRMATIONS_COUNT,
+            self.network_num, self.DEFAULT_FINAL_TX_CONFIRMATIONS_COUNT
+        )
 
         return self.DEFAULT_FINAL_TX_CONFIRMATIONS_COUNT
 
@@ -1167,12 +1117,13 @@ class TransactionService:
         """
         Returns configuration value of expiration time for transaction hashes removed from cache
         """
-        for blockchain_network in self.node.opts.blockchain_networks:
-            if blockchain_network.network_num == self.network_num:
-                return blockchain_network.removed_transactions_history_expiration_s
+        if self.network:
+            return self.network.removed_transactions_history_expiration_s
 
-        logger.warning(log_messages.UNABLE_TO_DETERMINE_TX_EXPIRATION_TIME,
-                       self.network_num, constants.REMOVED_TRANSACTIONS_HISTORY_EXPIRATION_S)
+        logger.warning(
+            log_messages.UNABLE_TO_DETERMINE_TX_EXPIRATION_TIME,
+            self.network_num, constants.REMOVED_TRANSACTIONS_HISTORY_EXPIRATION_S
+        )
 
         return constants.REMOVED_TRANSACTIONS_HISTORY_EXPIRATION_S
 
@@ -1184,19 +1135,20 @@ class TransactionService:
             # convert MB to bytes
             return int(self.node.opts.transaction_pool_memory_limit * 1024 * 1024)
 
-        for blockchain_network in self.node.opts.blockchain_networks:
-            if blockchain_network.network_num == self.network_num:
-                if blockchain_network.tx_contents_memory_limit_bytes is None:
-                    logger.warning(
-                        log_messages.TX_CACHE_SIZE_LIMIT_NOT_CONFIGURED,
-                        self.network_num, constants.DEFAULT_TX_CACHE_MEMORY_LIMIT_BYTES
-                    )
-                    return constants.DEFAULT_TX_CACHE_MEMORY_LIMIT_BYTES
-                else:
-                    return blockchain_network.tx_contents_memory_limit_bytes
+        if self.network:
+            if self.network.tx_contents_memory_limit_bytes is None:
+                logger.warning(
+                    log_messages.TX_CACHE_SIZE_LIMIT_NOT_CONFIGURED,
+                    self.network_num, constants.DEFAULT_TX_CACHE_MEMORY_LIMIT_BYTES
+                )
+                return constants.DEFAULT_TX_CACHE_MEMORY_LIMIT_BYTES
+            else:
+                return self.network.tx_contents_memory_limit_bytes
 
-        logger.warning(log_messages.UNABLE_TO_DETERMINE_TX_MEMORY_LIMIT,
-                       self.network_num, constants.DEFAULT_TX_CACHE_MEMORY_LIMIT_BYTES)
+        logger.warning(
+            log_messages.UNABLE_TO_DETERMINE_TX_MEMORY_LIMIT,
+            self.network_num, constants.DEFAULT_TX_CACHE_MEMORY_LIMIT_BYTES
+        )
         return constants.DEFAULT_TX_CACHE_MEMORY_LIMIT_BYTES
 
     def _tx_hash_to_cache_key(self, transaction_hash: Union[Sha256Hash, bytes, bytearray, memoryview, str]) -> str:
@@ -1245,11 +1197,15 @@ class TransactionService:
     def _is_exceeding_memory_limit(self) -> bool:
         return self._total_tx_contents_size > self._tx_content_memory_limit
 
-    def _clear(self) -> None:
+    def clear(self) -> None:
         self._tx_cache_key_to_contents.clear()
         self._tx_cache_key_to_short_ids.clear()
         self._short_id_to_tx_cache_key.clear()
         self._short_ids_seen_in_block.clear()
+        self._short_id_to_tx_quota_flag.clear()
+        self.tx_hashes_without_content.clear()
+        self.tx_hashes_without_short_id.clear()
+        self._tx_assignment_expire_queue.clear()
         self._total_tx_contents_size = 0
 
     # TODO: remove this unused function
@@ -1279,45 +1235,3 @@ class TransactionService:
              }
         )
         return constants.TRANSACTION_SERVICE_LOG_TRANSACTIONS_INTERVAL_S
-
-    def _cleanup_removed_transactions_history(self) -> int:
-        """
-        Removes expired items from the queue
-        :param current_time: time to use as current time for expiration
-        :param remove_callback: reference to a callback function that is being called when item is removed
-        :param args: arguments to pass into the callback method
-        :param kwargs: keyword args to pass into the callback method
-        """
-        logger.trace(
-            "Starting to cleanup transaction cache history for network "
-            "number: {}.",
-            self.network_num
-        )
-
-        current_time = time.time()
-        history_len_before = len(self._tx_hash_to_time_removed)
-
-        if self._tx_hash_to_time_removed:
-
-            oldest_tx = next(iter(self._tx_hash_to_time_removed))
-
-            while (self._tx_hash_to_time_removed and
-                   ((current_time - self._tx_hash_to_time_removed[oldest_tx] > self._removed_txs_expiration_time_s) or
-                    len(self._tx_hash_to_time_removed) > constants.REMOVED_TRANSACTIONS_HISTORY_LENGTH_LIMIT)):
-
-                del self._tx_hash_to_time_removed[oldest_tx]
-
-                if not self._tx_hash_to_time_removed:
-                    break
-
-                oldest_tx = next(iter(self._tx_hash_to_time_removed))
-
-        history_len_after = len(self._tx_hash_to_time_removed)
-        logger.trace(
-            "Finished cleanup transaction cache history. Size before: {}. "
-            "Size after: {}.",
-            history_len_before,
-            history_len_after
-        )
-
-        return constants.REMOVED_TRANSACTIONS_HISTORY_CLEANUP_INTERVAL_S
