@@ -215,10 +215,12 @@ class AlarmQueue:
                     except Exception as e:
                         logger.exception("Alarm {} could not fire and failed with exception: {}", alarm, e)
                     else:
-                        performance_utils.log_operation_duration(alarm_troubleshooting_logger,
-                                                                 "Single alarm", start_time,
-                                                                 constants.WARN_ALARM_EXECUTION_DURATION,
-                                                                 alarm=alarm)
+                        performance_utils.log_operation_duration(
+                            alarm_troubleshooting_logger,
+                            "Single alarm", start_time,
+                            constants.WARN_ALARM_EXECUTION_DURATION,
+                            alarm=alarm
+                        )
 
                         if next_delay is not None and next_delay > 0:
                             next_time = time.time() + next_delay
