@@ -1,15 +1,17 @@
 import time
 from abc import ABCMeta
+from asyncio import Future
 from typing import TYPE_CHECKING, Set
 
 from bxcommon import constants
 from bxcommon.connections.connection_type import ConnectionType
 from bxcommon.connections.internal_node_connection import InternalNodeConnection
-from bxcommon.messages.bloxroute.blockchain_network_message import RefreshBlockchainNetworkMessage
 from bxcommon.messages.bloxroute.abstract_cleanup_message import AbstractCleanupMessage
 from bxcommon.messages.bloxroute.bdn_performance_stats_message import BdnPerformanceStatsMessage
+from bxcommon.messages.bloxroute.blockchain_network_message import RefreshBlockchainNetworkMessage
 from bxcommon.messages.bloxroute.bloxroute_message_type import BloxrouteMessageType
 from bxcommon.messages.bloxroute.bloxroute_message_validator import BloxrouteMessageValidator
+from bxcommon.messages.bloxroute.compressed_block_txs_message import CompressedBlockTxsMessage
 from bxcommon.messages.bloxroute.disconnect_relay_peer_message import DisconnectRelayPeerMessage
 from bxcommon.messages.bloxroute.hello_message import HelloMessage
 from bxcommon.messages.bloxroute.notification_message import NotificationMessage
@@ -23,16 +25,19 @@ from bxcommon.utils import convert, performance_utils
 from bxcommon.utils import memory_utils
 from bxcommon.utils.object_hash import Sha256Hash
 from bxcommon.utils.stats import hooks, stats_format
+from bxcommon.utils.stats.block_stat_event_type import BlockStatEventType
+from bxcommon.utils.stats.block_statistics_service import block_stats
 from bxcommon.utils.stats.transaction_stat_event_type import TransactionStatEventType
 from bxcommon.utils.stats.transaction_statistics_service import tx_stats
 from bxgateway import log_messages, gateway_constants
 from bxgateway.feed.new_transaction_feed import NewTransactionFeed, RawTransactionFeedEntry
+from bxgateway.services.block_recovery_service import RecoveredTxsSource
+from bxgateway.services.gateway_transaction_service import MissingTransactions
 from bxgateway.utils.logging.status import status_log
 from bxgateway.utils.stats.gateway_bdn_performance_stats_service import gateway_bdn_performance_stats_service, \
     GatewayBdnPerformanceStatInterval
 from bxgateway.utils.stats.gateway_transaction_stats_service import gateway_transaction_stats_service
 from bxgateway.utils.stats.transaction_feed_stats_service import transaction_feed_stats_service
-from bxgateway.services.gateway_transaction_service import MissingTransactions
 from bxutils import logging
 from bxutils.logging import LogLevel
 from bxutils.logging import LogRecordType
@@ -67,10 +72,11 @@ class AbstractRelayConnection(InternalNodeConnection["AbstractGatewayNode"]):
             BloxrouteMessageType.KEY: self.msg_key,
             BloxrouteMessageType.TRANSACTION: self.msg_tx,
             BloxrouteMessageType.TRANSACTIONS: self.msg_txs,
+            BloxrouteMessageType.COMPRESSED_BLOCK_TXS: self.msg_compressed_block_txs,
             BloxrouteMessageType.BLOCK_HOLDING: self.msg_block_holding,
             BloxrouteMessageType.DISCONNECT_RELAY_PEER: self.msg_disconnect_relay_peer,
-            BloxrouteMessageType.TX_SERVICE_SYNC_TXS: self.msg_tx_service_sync_txs,
-            BloxrouteMessageType.TX_SERVICE_SYNC_COMPLETE: self.msg_tx_service_sync_complete,
+            BloxrouteMessageType.TX_SERVICE_SYNC_TXS: self.tx_sync_service.msg_tx_service_sync_txs,
+            BloxrouteMessageType.TX_SERVICE_SYNC_COMPLETE: self.tx_sync_service.msg_tx_service_sync_complete,
             BloxrouteMessageType.BLOCK_CONFIRMATION: self.msg_cleanup,
             BloxrouteMessageType.TRANSACTION_CLEANUP: self.msg_cleanup,
             BloxrouteMessageType.NOTIFICATION: self.msg_notify,
@@ -83,7 +89,7 @@ class AbstractRelayConnection(InternalNodeConnection["AbstractGatewayNode"]):
 
     def msg_hello(self, msg):
         super(AbstractRelayConnection, self).msg_hello(msg)
-        self.node.on_relay_connection_ready()
+        self.node.on_relay_connection_ready(self.CONNECTION_TYPE)
 
     def msg_broadcast(self, msg):
         """
@@ -171,7 +177,7 @@ class AbstractRelayConnection(InternalNodeConnection["AbstractGatewayNode"]):
         )
 
         if processing_result.assigned_short_id:
-            was_missing = self.node.block_recovery_service.check_missing_sid(short_id)
+            was_missing = self.node.block_recovery_service.check_missing_sid(short_id, RecoveredTxsSource.TXS_RECEIVED_FROM_BDN)
             attempt_recovery |= was_missing
             tx_stats.add_tx_by_hash_event(
                 tx_hash,
@@ -195,23 +201,28 @@ class AbstractRelayConnection(InternalNodeConnection["AbstractGatewayNode"]):
 
         if processing_result.set_content:
             self.log_trace("Adding hash value to tx service and forwarding it to node")
-            gateway_bdn_performance_stats_service.log_tx_from_bdn()
-            attempt_recovery |= self.node.block_recovery_service.check_missing_tx_hash(tx_hash)
+            gateway_bdn_performance_stats_service.log_tx_from_bdn(
+                not self.node.is_gas_price_above_min_network_fee(tx_contents)
+            )
+            attempt_recovery |= self.node.block_recovery_service.check_missing_tx_hash(tx_hash, RecoveredTxsSource.TXS_RECEIVED_FROM_BDN)
+
+            self.publish_new_transaction(
+                tx_hash, tx_contents
+            )
 
             if self.node.node_conn is not None:
                 blockchain_tx_message = self.node.message_converter.bx_tx_to_tx(msg)
-                self.publish_new_transaction(
-                    tx_hash, tx_contents
-                )
                 transaction_feed_stats_service.log_new_transaction(tx_hash)
-                self.node.send_msg_to_node(blockchain_tx_message)
-
-                tx_stats.add_tx_by_hash_event(
-                    tx_hash,
-                    TransactionStatEventType.TX_SENT_FROM_GATEWAY_TO_BLOCKCHAIN_NODE,
-                    network_num,
-                    short_id
-                )
+                sent = self.node.send_transaction_to_node(blockchain_tx_message)
+                if sent:
+                    tx_stats.add_tx_by_hash_event(
+                        tx_hash,
+                        TransactionStatEventType.TX_SENT_FROM_GATEWAY_TO_BLOCKCHAIN_NODE,
+                        network_num,
+                        short_id
+                    )
+                else:
+                    gateway_transaction_stats_service.log_dropped_transaction_from_relay()
 
         if attempt_recovery:
             self.node.block_processing_service.retry_broadcast_recovered_blocks(self)
@@ -243,10 +254,11 @@ class AbstractRelayConnection(InternalNodeConnection["AbstractGatewayNode"]):
             duration_after_ext_ms=duration_after_ext_ms
         )
 
-    def msg_txs(self, msg: TxsMessage):
+    def msg_txs(self, msg: TxsMessage, recovered_txs_source: RecoveredTxsSource = RecoveredTxsSource.TXS_RECOVERED):
         transactions = msg.get_txs()
         tx_service = self.node.get_tx_service()
         missing_txs: Set[MissingTransactions] = tx_service.process_txs_message(msg)
+
         tx_stats.add_txs_by_short_ids_event(
             map(lambda x: x.short_id, transactions),
             TransactionStatEventType.TX_UNKNOWN_SHORT_IDS_REPLY_RECEIVED_BY_GATEWAY_FROM_RELAY,
@@ -258,8 +270,8 @@ class AbstractRelayConnection(InternalNodeConnection["AbstractGatewayNode"]):
         )
 
         for (short_id, transaction_hash) in missing_txs:
-            self.node.block_recovery_service.check_missing_sid(short_id)
-            self.node.block_recovery_service.check_missing_tx_hash(transaction_hash)
+            self.node.block_recovery_service.check_missing_sid(short_id, recovered_txs_source)
+            self.node.block_recovery_service.check_missing_tx_hash(transaction_hash, recovered_txs_source)
 
             tx_stats.add_tx_by_hash_event(
                 transaction_hash,
@@ -274,6 +286,21 @@ class AbstractRelayConnection(InternalNodeConnection["AbstractGatewayNode"]):
         for block_awaiting_recovery in self.node.block_recovery_service.get_blocks_awaiting_recovery():
             self.node.block_processing_service.schedule_recovery_retry(block_awaiting_recovery)
 
+    def msg_compressed_block_txs(self, msg: CompressedBlockTxsMessage):
+        start_time = time.time()
+
+        self.msg_txs(msg.to_txs_message(), RecoveredTxsSource.COMPRESSED_BLOCK_TXS_RECEIVED)
+
+        block_stats.add_block_event_by_block_hash(
+            msg.block_hash(),
+            BlockStatEventType.ENC_BLOCK_COMPRESSED_TXS_RECEIVED_BY_GATEWAY,
+            network_num=msg.network_num(),
+            more_info="{}. processing time: {}".format(
+                stats_format.connection(self),
+                stats_format.timespan(start_time, time.time())
+            )
+        )
+
     def msg_block_holding(self, msg):
         """
         Block holding request message handler. Places block on hold and broadcasts message to relay and gateway peers.
@@ -338,10 +365,22 @@ class AbstractRelayConnection(InternalNodeConnection["AbstractGatewayNode"]):
                 self.node.alarm_queue.register_approx_alarm(
                     2 * constants.MIN_SLEEP_TIMEOUT, constants.MIN_SLEEP_TIMEOUT, status_log.update_alarm_callback,
                     self.node.connection_pool, self.node.opts.use_extensions, self.node.opts.source_version,
-                    self.node.opts.external_ip, self.node.opts.continent, self.node.opts.country,
+                    self.node.opts.external_ip, self.node.opts.continent, self.node.opts.country, self.node.opts.region,
                     self.node.opts.should_update_source_version, self.node.account_id,
                     self.node.quota_level
                 )
+        elif (
+            msg.notification_code() == NotificationCode.ASSIGNING_SHORT_IDS
+            or msg.notification_code() == NotificationCode.NOT_ASSIGNING_SHORT_IDS
+        ):
+            is_assigning = msg.notification_code() == NotificationCode.ASSIGNING_SHORT_IDS
+            peer_model = self.peer_model
+            if peer_model is not None:
+                peer_model.assigning_short_ids = is_assigning
+            if self.node.opts.split_relays:
+                for peer_model in self.node.peer_transaction_relays:
+                    if peer_model.ip == self.peer_ip and peer_model.node_id == self.peer_id:
+                        peer_model.assigning_short_ids = is_assigning
 
         if msg.level() == LogLevel.WARNING or msg.level() == LogLevel.ERROR:
             self.log(msg.level(), log_messages.NOTIFICATION_FROM_RELAY, msg.formatted_message())
@@ -350,22 +389,34 @@ class AbstractRelayConnection(InternalNodeConnection["AbstractGatewayNode"]):
 
     def msg_refresh_blockchain_network(self, _msg: RefreshBlockchainNetworkMessage) -> None:
         blockchain_protocol = self.node.opts.blockchain_protocol
-        assert blockchain_protocol is not None
         blockchain_network = self.node.opts.blockchain_network
+        assert blockchain_protocol is not None
         assert blockchain_network is not None
 
-        updated_blockchain_network = sdn_http_service.fetch_blockchain_network(blockchain_protocol, blockchain_network)
-        assert updated_blockchain_network is not None
-        self.node.opts.enable_block_compression = updated_blockchain_network.enable_block_compression
-
-        for blockchain_network_config in self.node.opts.blockchain_networks:
-            if blockchain_network_config.protocol.lower() == blockchain_protocol.lower() \
-                    and blockchain_network_config.network.lower() == blockchain_network.lower():
-                blockchain_network_config.enable_block_compression = self.node.opts.enable_block_compression
-                break
+        self.node.requester.send_threaded_request(
+            sdn_http_service.fetch_blockchain_network,
+            blockchain_protocol,
+            blockchain_network,
+            # pyre-fixme[6]: Expected `Optional[Callable[[Future[Any]], Any]]` for 4th parameter `done_callback`
+            #  to call `send_threaded_request` but got `BoundMethod[Callable(_process_blockchain_network_from_sdn)
+            #  [[Named(self, AbstractRelayConnection), Named(get_blockchain_network_future, Future[Any])], Any],
+            #  AbstractRelayConnection]`.
+            done_callback=self._process_blockchain_network_from_sdn
+        )
 
     def publish_new_transaction(self, tx_hash: Sha256Hash, tx_contents: memoryview) -> None:
         self.node.feed_manager.publish_to_feed(
             NewTransactionFeed.NAME,
             RawTransactionFeedEntry(tx_hash, tx_contents)
         )
+
+    def _process_blockchain_network_from_sdn(self, get_blockchain_network_future: Future):
+        try:
+            updated_blockchain_network = get_blockchain_network_future.result()
+            assert updated_blockchain_network is not None
+
+            self.node.network = updated_blockchain_network
+            self.node.opts.blockchain_networks[self.node.network_num] = updated_blockchain_network
+            self.node.update_node_settings_from_blockchain_network(updated_blockchain_network)
+        except Exception as e:
+            self.log_info("Got {} when trying to read blockchain network from sdn", e)
\ No newline at end of file
