@@ -1,19 +1,22 @@
+import time
 from collections import deque
 from typing import List, Deque
-from time import time
 
 from bxcommon.messages.abstract_message import AbstractMessage
 from bxcommon.utils import convert
 from bxcommon.utils.blockchain_utils.eth import eth_common_utils, eth_common_constants
 from bxcommon.utils.expiring_dict import ExpiringDict
 from bxcommon.utils.object_hash import Sha256Hash, NULL_SHA256_HASH
+from bxcommon.utils.stats import stats_format
 from bxcommon.utils.stats.block_stat_event_type import BlockStatEventType
 from bxcommon.utils.stats.block_statistics_service import block_stats
+from bxgateway import log_messages
 from bxgateway.connections.eth.eth_base_connection_protocol import EthBaseConnectionProtocol
 from bxgateway.eth_exceptions import CipherNotInitializedError
 from bxgateway.feed.eth.eth_new_transaction_feed import EthNewTransactionFeed
-from bxgateway.feed.eth.eth_raw_transaction import EthRawTransaction
 from bxgateway.feed.eth.eth_pending_transaction_feed import EthPendingTransactionFeed
+from bxgateway.feed.eth.eth_raw_transaction import EthRawTransaction
+from bxgateway.feed.new_transaction_feed import FeedSource
 from bxgateway.messages.eth.internal_eth_block_info import InternalEthBlockInfo
 from bxgateway.messages.eth.new_block_parts import NewBlockParts
 from bxgateway.messages.eth.protocol.block_bodies_eth_protocol_message import BlockBodiesEthProtocolMessage
@@ -25,7 +28,9 @@ from bxgateway.messages.eth.protocol.get_receipts_eth_protocol_message import Ge
 from bxgateway.messages.eth.protocol.new_block_eth_protocol_message import NewBlockEthProtocolMessage
 from bxgateway.messages.eth.protocol.new_block_hashes_eth_protocol_message import NewBlockHashesEthProtocolMessage
 from bxgateway.messages.eth.protocol.status_eth_protocol_message import StatusEthProtocolMessage
-from bxgateway import log_messages
+from bxgateway.messages.eth.protocol.transactions_eth_protocol_message import \
+    TransactionsEthProtocolMessage
+from bxgateway.utils.stats.gateway_transaction_stats_service import gateway_transaction_stats_service
 from bxutils import logging
 
 logger = logging.get_logger(__name__)
@@ -63,7 +68,8 @@ class EthNodeConnectionProtocol(EthBaseConnectionProtocol):
         self._ready_new_blocks: Deque[Sha256Hash] = deque()
 
         # queue of lists of hashes that are awaiting block bodies response
-        self._block_bodies_requests: Deque[List[Sha256Hash]] = deque(maxlen=eth_common_constants.REQUESTED_NEW_BLOCK_BODIES_MAX_COUNT)
+        self._block_bodies_requests: Deque[List[Sha256Hash]] = deque(
+            maxlen=eth_common_constants.REQUESTED_NEW_BLOCK_BODIES_MAX_COUNT)
 
         if self.block_cleanup_poll_interval_s > 0:
             self.connection.node.alarm_queue.register_alarm(
@@ -78,30 +84,43 @@ class EthNodeConnectionProtocol(EthBaseConnectionProtocol):
             eth_common_constants.BLOCK_CONFIRMATION_REQUEST_CACHE_INTERVAL_S,
             f"{str(self)}_eth_requested_blocks"
         )
+        self._connection_established_time = 0.0
 
     def msg_status(self, msg: StatusEthProtocolMessage):
         super(EthNodeConnectionProtocol, self).msg_status(msg)
         self.connection.on_connection_established()
 
-        self.node.alarm_queue.register_alarm(
-            self.connection.ping_interval_s,
-            self.connection.send_ping
-        )
+        self.connection.schedule_pings()
 
         self.node.on_blockchain_connection_ready(self.connection)
-        self.node.alarm_queue.register_alarm(eth_common_constants.CHECKPOINT_BLOCK_HEADERS_REQUEST_WAIT_TIME_S,
-                                             self._stop_waiting_checkpoint_headers_request)
+        self.node.alarm_queue.register_alarm(
+            eth_common_constants.CHECKPOINT_BLOCK_HEADERS_REQUEST_WAIT_TIME_S,
+            self._stop_waiting_checkpoint_headers_request
+        )
+
+        self._connection_established_time = time.time()
+
+    def msg_tx(self, msg: TransactionsEthProtocolMessage) -> None:
+        if len(msg.rawbytes()) >= eth_common_constants.ETH_SKIP_TRANSACTIONS_SIZE:
+            bytes_skipped_count = len(msg.rawbytes())
+            self.connection.log_debug("Skipping {} bytes of transactions message.", bytes_skipped_count)
+            gateway_transaction_stats_service.log_skipped_transaction_bytes(bytes_skipped_count)
+        else:
+            super().msg_tx(msg)
 
     # pyre-fixme[14]: `msg_block` overrides method defined in
     #  `AbstractBlockchainConnectionProtocol` inconsistently.
-    def msg_block(self, msg: NewBlockEthProtocolMessage):
+    def msg_block(self, msg: NewBlockEthProtocolMessage) -> None:
         if not self.node.should_process_block_hash(msg.block_hash()):
             return
 
-        self.node.set_known_total_difficulty(msg.block_hash(), msg.chain_difficulty())
+        self.node.set_known_total_difficulty(msg.block_hash(), msg.get_chain_difficulty())
 
         internal_new_block_msg = InternalEthBlockInfo.from_new_block_msg(msg)
-        super().msg_block(internal_new_block_msg)
+        self.process_msg_block(internal_new_block_msg, msg.number())
+
+        if self.node.opts.filter_txs_factor > 0:
+            self.node.on_transactions_in_block(msg.txns())
 
     def msg_new_block_hashes(self, msg: NewBlockHashesEthProtocolMessage):
         if not self.node.should_process_block_hash(msg.block_hash()):
@@ -135,9 +154,14 @@ class EthNodeConnectionProtocol(EthBaseConnectionProtocol):
                 )
                 continue
 
+            recovery_cancelled = self.node.on_block_seen_by_blockchain_node(
+                block_hash, block_number=block_number
+            )
+            if recovery_cancelled:
+                continue
+
             self.node.track_block_from_node_handling_started(block_hash)
             block_hash_number_pairs.append((block_hash, block_number))
-            self.node.on_block_seen_by_blockchain_node(block_hash, block_number=block_number)
 
             self.connection.log_info(
                 "Fetching block {} from local Ethereum node.",
@@ -309,26 +333,28 @@ class EthNodeConnectionProtocol(EthBaseConnectionProtocol):
         for block_hash in hashes:
             last_attempt = self.requested_blocks_for_confirmation.contents.get(block_hash, 0)
             if time() - last_attempt > \
-                    self.block_cleanup_poll_interval_s * eth_common_constants.BLOCK_CONFIRMATION_REQUEST_INTERVALS:
+                self.block_cleanup_poll_interval_s * eth_common_constants.BLOCK_CONFIRMATION_REQUEST_INTERVALS:
                 break
         else:
             block_hash = hashes[0]
 
-        self.requested_blocks_for_confirmation.add(block_hash, time())
+        self.requested_blocks_for_confirmation.add(block_hash, time.time())
         return GetBlockHeadersEthProtocolMessage(
-                None,
-                block_hash=bytes(block_hash.binary),
-                amount=100,
-                skip=0,
-                reverse=0
-            )
+            None,
+            block_hash=bytes(block_hash.binary),
+            amount=100,
+            skip=0,
+            reverse=0
+        )
 
     def publish_transaction(
         self, tx_hash: Sha256Hash, tx_contents: memoryview
     ) -> None:
         self.node.feed_manager.publish_to_feed(
-            EthNewTransactionFeed.NAME, EthRawTransaction(tx_hash, tx_contents)
+            EthNewTransactionFeed.NAME,
+            EthRawTransaction(tx_hash, tx_contents, FeedSource.BLOCKCHAIN_SOCKET)
         )
         self.node.feed_manager.publish_to_feed(
-            EthPendingTransactionFeed.NAME, EthRawTransaction(tx_hash, tx_contents)
+            EthPendingTransactionFeed.NAME,
+            EthRawTransaction(tx_hash, tx_contents, FeedSource.BLOCKCHAIN_SOCKET)
         )
