@@ -176,7 +176,7 @@ PONG_MESSAGE_TIMEOUT = LogMessage(
     CONNECTION_PROBLEM_CATEGORY,
     "Pong message was not received within allocated timeout connection. Closing."
 )
-BLOCK_REQUIRES_RECOVERY = LogMessage(
+_BLOCK_REQUIRES_RECOVERY = LogMessage(
     "G-000033",
     GENERAL_CATEGORY,
     "Block {} requires short id recovery. Querying BDN..."
@@ -282,7 +282,7 @@ BLOCK_COMPRESSION_FAIL_ONT_CONSENSUS = LogMessage(
     PROCESSING_FAILED_CATEGORY,
     "Failed to compress consensus block {} - {}"
 )
-BLOCK_REQUIRES_RECOVERY_ONT_CONSENSUS = LogMessage(
+_BLOCK_REQUIRES_RECOVERY_ONT_CONSENSUS = LogMessage(
     "G-000053",
     GENERAL_CATEGORY,
     "Consensus block {} requires short id recovery. Querying BDN..."
@@ -368,7 +368,7 @@ BAD_FEED_SUBSCRIBER = LogMessage(
     "G-000068",
     GENERAL_CATEGORY,
     "Subscriber {} was not receiving messages and emptying its queue from "
-    "feed {}. Disconnecting.",
+    "{}. Disconnecting.",
 )
 BAD_RPC_SUBSCRIBER = LogMessage(
     "G-000069",
@@ -428,3 +428,14 @@ COULD_NOT_SERIALIZE_FEED_ENTRY = LogMessage(
     PROCESSING_FAILED_CATEGORY,
     "Could not serialize feed entry. Skipping."
 )
+MISSING_TRANSACTION_STREAMER_PEER_INFO = LogMessage(
+    "G-000080",
+    CONNECTION_PROBLEM_CATEGORY,
+    "Missing transaction streamer peer info upon feed subscription. Connect attempt aborted. Please retry subscription if "
+    "you wish to subscribe to the pendingTxs feed and local Ethereum validation is not enabled via --eth-ws-uri."
+)
+COULD_NOT_DESERIALIZE_BLOCK = LogMessage(
+    "G-000081",
+    PROCESSING_FAILED_CATEGORY,
+    "Could not deserialize block to Ethereum payload: {}, body: {}. Error: {}",
+)
