@@ -2,7 +2,7 @@ import rlp
 
 from bxgateway.messages.eth.protocol.eth_protocol_message import EthProtocolMessage
 from bxgateway.messages.eth.protocol.eth_protocol_message_type import EthProtocolMessageType
-from bxgateway.utils.eth import rlp_utils
+from bxcommon.utils.blockchain_utils.eth import rlp_utils
 
 
 class ReceiptsEthProtocolMessage(EthProtocolMessage):
