@@ -1,11 +1,13 @@
 import datetime
 import time
+import typing
 from typing import Iterable, Optional, TYPE_CHECKING
 
 from bxcommon.connections.connection_type import ConnectionType
+from bxcommon.messages.abstract_block_message import AbstractBlockMessage
 from bxcommon.messages.bloxroute.block_holding_message import BlockHoldingMessage
 from bxcommon.messages.bloxroute.get_txs_message import GetTxsMessage
-from bxcommon.utils import convert, crypto
+from bxcommon.utils import convert, crypto, block_content_debug_utils
 from bxcommon.utils.expiring_dict import ExpiringDict
 from bxcommon.utils.object_hash import Sha256Hash
 from bxcommon.utils.stats import stats_format
@@ -15,14 +17,15 @@ from bxcommon.utils.stats.stat_block_type import StatBlockType
 from bxcommon.utils.stats.transaction_stat_event_type import TransactionStatEventType
 from bxcommon.utils.stats.transaction_statistics_service import tx_stats
 from bxgateway import gateway_constants
+from bxgateway import log_messages
 from bxgateway.connections.abstract_gateway_blockchain_connection import AbstractGatewayBlockchainConnection
 from bxgateway.connections.abstract_relay_connection import AbstractRelayConnection
+from bxgateway.feed.feed_source import FeedSource
 from bxgateway.messages.gateway.block_received_message import BlockReceivedMessage
-from bxgateway.services.block_recovery_service import BlockRecoveryInfo
+from bxgateway.services.block_recovery_service import BlockRecoveryInfo, RecoveredTxsSource
 from bxgateway.utils.errors.message_conversion_error import MessageConversionError
 from bxgateway.utils.stats.gateway_bdn_performance_stats_service import gateway_bdn_performance_stats_service
 from bxutils import logging
-from bxgateway import log_messages
 
 if TYPE_CHECKING:
     from bxgateway.connections.abstract_gateway_node import AbstractGatewayNode
@@ -118,15 +121,21 @@ class BlockProcessingService:
                 hold.block_message = block_message
                 hold.connection = connection
         else:
-            # Broadcast BlockHoldingMessage through relays and gateways
-            conns = self._node.broadcast(BlockHoldingMessage(block_hash, self._node.network_num),
-                                         broadcasting_conn=connection, prepend_to_queue=True,
-                                         connection_types=[ConnectionType.RELAY_BLOCK, ConnectionType.GATEWAY])
-            if len(conns) > 0:
-                block_stats.add_block_event_by_block_hash(block_hash,
-                                                          BlockStatEventType.BLOCK_HOLD_SENT_BY_GATEWAY_TO_PEERS,
-                                                          network_num=self._node.network_num,
-                                                          more_info=stats_format.connections(conns))
+            if self._node.opts.encrypt_blocks:
+                # Broadcast holding message if gateway wants to encrypt blocks
+                conns = self._node.broadcast(
+                    BlockHoldingMessage(block_hash, self._node.network_num),
+                    broadcasting_conn=connection,
+                    prepend_to_queue=True,
+                    connection_types=[ConnectionType.RELAY_BLOCK, ConnectionType.GATEWAY]
+                )
+                if len(conns) > 0:
+                    block_stats.add_block_event_by_block_hash(
+                        block_hash,
+                        BlockStatEventType.BLOCK_HOLD_SENT_BY_GATEWAY_TO_PEERS,
+                        network_num=self._node.network_num,
+                        more_info=stats_format.connections(conns)
+                    )
             self._process_and_broadcast_block(block_message, connection)
 
     def cancel_hold_timeout(self, block_hash, connection) -> None:
@@ -266,8 +275,8 @@ class BlockProcessingService:
 
     def retry_broadcast_recovered_blocks(self, connection) -> None:
         if self._node.block_recovery_service.recovered_blocks and self._node.opts.has_fully_updated_tx_service:
-            for msg in self._node.block_recovery_service.recovered_blocks:
-                self._handle_decrypted_block(msg, connection, recovered=True)
+            for msg, recovery_source in self._node.block_recovery_service.recovered_blocks:
+                self._handle_decrypted_block(msg, connection, recovered=True, recovered_txs_source=recovery_source)
 
             self._node.block_recovery_service.clean_up_recovered_blocks()
 
@@ -297,7 +306,10 @@ class BlockProcessingService:
         assert message_converter is not None
         try:
             bx_block, block_info = message_converter.block_to_bx_block(
-                block_message, self._node.get_tx_service(), self._node.opts.enable_block_compression
+                block_message,
+                self._node.get_tx_service(),
+                self._node.opts.enable_block_compression,
+                self._node.network.min_tx_age_seconds
             )
         except MessageConversionError as e:
             block_stats.add_block_event_by_block_hash(
@@ -309,6 +321,13 @@ class BlockProcessingService:
             connection.log_error(log_messages.BLOCK_COMPRESSION_FAIL, e.msg_hash, e)
             return
 
+        if block_info.ignored_short_ids:
+            assert block_info.ignored_short_ids is not None
+            logger.debug(
+                "Ignoring {} new SIDs for {}: {}",
+                len(block_info.ignored_short_ids), block_info.block_hash, block_info.ignored_short_ids
+            )
+
         compression_rate = block_info.compression_rate
         assert compression_rate is not None
         block_stats.add_block_event_by_block_hash(
@@ -368,7 +387,8 @@ class BlockProcessingService:
         bx_block: memoryview,
         connection: AbstractRelayConnection,
         encrypted_block_hash_hex: Optional[str] = None,
-        recovered: bool = False
+        recovered: bool = False,
+        recovered_txs_source: Optional[RecoveredTxsSource] = None
     ) -> None:
         transaction_service = self._node.get_tx_service()
         message_converter = self._node.message_converter
@@ -380,6 +400,7 @@ class BlockProcessingService:
                 (
                     block_message, block_info, unknown_sids, unknown_hashes
                 ) = message_converter.bx_block_to_block(bx_block, transaction_service)
+                block_content_debug_utils.log_compressed_block_debug_info(transaction_service, bx_block)
             except MessageConversionError as e:
                 block_stats.add_block_event_by_block_hash(
                     e.msg_hash,
@@ -412,7 +433,8 @@ class BlockProcessingService:
             block_stats.add_block_event_by_block_hash(
                 block_hash,
                 BlockStatEventType.BLOCK_RECOVERY_COMPLETED,
-                network_num=connection.network_num
+                network_num=connection.network_num,
+                more_info=str(recovered_txs_source)
             )
 
         if block_hash in self._node.blocks_seen.contents:
@@ -438,6 +460,8 @@ class BlockProcessingService:
                 "Discarding duplicate block {} from the BDN.",
                 block_hash
             )
+            if not self._node.block_queuing_service.block_body_exists(block_hash):
+                self._node.block_queuing_service.store_block_data(block_hash, block_message)
             return
 
         if not recovered:
@@ -482,29 +506,35 @@ class BlockProcessingService:
             self._node.block_recovery_service.cancel_recovery_for_block(block_hash)
             self._node.blocks_seen.add(block_hash)
             transaction_service.track_seen_short_ids(block_hash, all_sids)
+
+            self._node.publish_block(
+                None, block_hash, typing.cast(AbstractBlockMessage, block_message), FeedSource.BDN_SOCKET
+            )
         else:
             if block_hash in self._node.block_queuing_service and not recovered:
                 connection.log_trace("Handling already queued block again. Ignoring.")
                 return
 
             self._node.block_recovery_service.add_block(bx_block, block_hash, unknown_sids, unknown_hashes)
-            block_stats.add_block_event_by_block_hash(block_hash,
-                                                      BlockStatEventType.BLOCK_DECOMPRESSED_WITH_UNKNOWN_TXS,
-                                                      start_date_time=block_info.start_datetime,
-                                                      end_date_time=block_info.end_datetime,
-                                                      network_num=connection.network_num,
-                                                      prev_block_hash=block_info.prev_block_hash,
-                                                      original_size=block_info.original_size,
-                                                      compressed_size=block_info.compressed_size,
-                                                      txs_count=block_info.txn_count,
-                                                      blockchain_network=self._node.opts.blockchain_network,
-                                                      blockchain_protocol=self._node.opts.blockchain_protocol,
-                                                      matching_block_hash=block_info.compressed_block_hash,
-                                                      matching_block_type=StatBlockType.COMPRESSED.value,
-                                                      more_info="{} sids, {} hashes".format(
-                                                          len(unknown_sids), len(unknown_hashes)))
+            block_stats.add_block_event_by_block_hash(
+                block_hash,
+                BlockStatEventType.BLOCK_DECOMPRESSED_WITH_UNKNOWN_TXS,
+                start_date_time=block_info.start_datetime,
+                end_date_time=block_info.end_datetime,
+                network_num=connection.network_num,
+                prev_block_hash=block_info.prev_block_hash,
+                original_size=block_info.original_size,
+                compressed_size=block_info.compressed_size,
+                txs_count=block_info.txn_count,
+                blockchain_network=self._node.opts.blockchain_network,
+                blockchain_protocol=self._node.opts.blockchain_protocol,
+                matching_block_hash=block_info.compressed_block_hash,
+                matching_block_type=StatBlockType.COMPRESSED.value,
+                more_info="{} sids, {} hashes, [{},...]".format(len(unknown_sids), len(unknown_hashes),
+                                                                unknown_sids[:5])
+            )
 
-            connection.log_warning(log_messages.BLOCK_REQUIRES_RECOVERY, block_hash)
+            connection.log_info("Block {} requires short id recovery. Querying BDN...", block_hash)
 
             self.start_transaction_recovery(unknown_sids, unknown_hashes, block_hash, connection)
             if recovered:
@@ -521,6 +551,15 @@ class BlockProcessingService:
         block_hash: Sha256Hash,
         connection: Optional[AbstractRelayConnection] = None
     ) -> None:
+        all_unknown_sids = []
+        all_unknown_sids.extend(unknown_sids)
+        tx_service = self._node.get_tx_service()
+
+        # retrieving sids of txs with unknown contents
+        for tx_hash in unknown_hashes:
+            tx_sid = tx_service.get_short_id(tx_hash)
+            all_unknown_sids.append(tx_sid)
+
         if not self._node.opts.request_recovery:
             if connection is not None:
                 network_num = connection.network_num
@@ -531,19 +570,11 @@ class BlockProcessingService:
                 block_hash,
                 BlockStatEventType.BLOCK_RECOVERY_STARTED,
                 network_num=network_num,
+                txs_count=len(all_unknown_sids),
                 more_info="recovery from relay is disabled",
             )
             return
 
-        all_unknown_sids = []
-        all_unknown_sids.extend(unknown_sids)
-        tx_service = self._node.get_tx_service()
-
-        # retrieving sids of txs with unknown contents
-        for tx_hash in unknown_hashes:
-            tx_sid = tx_service.get_short_id(tx_hash)
-            all_unknown_sids.append(tx_sid)
-
         get_txs_message = GetTxsMessage(short_ids=all_unknown_sids)
         self._node.broadcast(get_txs_message, connection_types=[ConnectionType.RELAY_TRANSACTION])
 
@@ -559,6 +590,7 @@ class BlockProcessingService:
                 block_hash,
                 BlockStatEventType.BLOCK_RECOVERY_STARTED,
                 network_num=connection.network_num,
+                txs_count=len(all_unknown_sids),
                 request_hash=convert.bytes_to_hex(
                     crypto.double_sha256(get_txs_message.rawbytes())
                 )
@@ -568,6 +600,7 @@ class BlockProcessingService:
                 block_hash,
                 BlockStatEventType.BLOCK_RECOVERY_REPEATED,
                 network_num=self._node.network_num,
+                txs_count=len(all_unknown_sids),
                 request_hash=convert.bytes_to_hex(
                     crypto.double_sha256(get_txs_message.rawbytes())
                 )
