@@ -21,7 +21,8 @@ class TestAbstractGatewayTransactionService(AbstractTransactionServiceTestCase,
             8000,
             include_default_eth_args=True,
             pub_key=pub_key,
-            track_detailed_sent_messages=True
+            track_detailed_sent_messages=True,
+            blockchain_network_num=5
         )
 
         if self.opts.use_extensions:
@@ -30,8 +31,15 @@ class TestAbstractGatewayTransactionService(AbstractTransactionServiceTestCase,
         self.transaction_service = self._get_transaction_service()
 
     def _test_process_transactions_message_from_node(self):
+        min_tx_network_fee = 0
+        if self.node.network_num in self.node.opts.blockchain_networks:
+            min_tx_network_fee = self.node.opts.blockchain_networks[self.node.network_num].min_tx_network_fee
+
         tx_message, test_txs_info = self._get_node_tx_message()
-        result = self.transaction_service.process_transactions_message_from_node(tx_message)
+        self.opts.transaction_validation = False
+        result = self.transaction_service.process_transactions_message_from_node(
+            tx_message, min_tx_network_fee, True
+        )
 
         self.assertIsNotNone(result)
         self.assertEqual(len(test_txs_info), len(result))
