@@ -41,7 +41,7 @@ def get_gateway_opts(
     block_interval=600,
     non_ssl_port: int = 9001,
     has_fully_updated_tx_service: bool = False,
-    max_block_interval: float = 10,
+    max_block_interval_s: float = 10,
     default_tx_quota_type: QuotaType = QuotaType.FREE_DAILY_QUOTA,
     log_level_overrides=None,
     enable_network_content_logs=False,
@@ -54,6 +54,8 @@ def get_gateway_opts(
     ws_port=28333,
     request_remote_transaction_streaming: bool = False,
     enable_block_compression: bool = True,
+    filter_txs_factor: float = 0,
+    blockchain_protocol: str = "Bitcoin",
     **kwargs,
 ) -> GatewayOpts:
     if node_id is None:
@@ -90,7 +92,7 @@ def get_gateway_opts(
             "bloxroute_version": bloxroute_version,
             "blockchain_ip": blockchain_address[0],
             "blockchain_port": blockchain_address[1],
-            "blockchain_protocol": "Bitcoin",
+            "blockchain_protocol": blockchain_protocol,
             "blockchain_network": "Mainnet",
             "blockchain_version": 12345,
             "test_mode": test_mode,
@@ -111,7 +113,7 @@ def get_gateway_opts(
             "compact_block_min_tx_count": BTC_COMPACT_BLOCK_DECOMPRESS_MIN_TX_COUNT,
             "tune_send_buffer_size": False,
             "dump_short_id_mapping_compression": False,
-            "max_block_interval": max_block_interval,
+            "max_block_interval_s": max_block_interval_s,
             "cookie_file_path": cookie_file_path,
             "config_update_interval": 60,
             "blockchain_message_ttl": 10,
@@ -138,6 +140,8 @@ def get_gateway_opts(
             "enable_eth_extensions": True,   # TODO remove,
             "request_recovery": True,
             "enable_block_compression": enable_block_compression,
+            "filter_txs_factor": filter_txs_factor,
+            "min_peer_relays_count": None
         }
     )
 
